@@ -37,8 +37,8 @@
 #include "../FlippedView.h"
 #include "../graphicsUndo.subproj/undo.h"
 
-static NSTextView	*drawText = nil;	/* shared Text object used for drawing */
-//static NSString		*fontListNoFill;	/* list of fonts which shouldn't be filled */
+static NSTextView	*drawText = nil;	// shared Text object used for drawing
+//static NSString	*fontListNoFill;	// list of fonts which shouldn't be filled
 //static BOOL 		displayModeFilled = YES;
 
 //#define FONTLIST_NAME	@"FontListNoFill"
@@ -252,7 +252,8 @@ static void initClassVars()
     [drawText setHorizontallyResizable:YES];
     [drawText setVerticallyResizable:YES];
     [ts beginEditing];
-    [ts setAttributedString:attributedString];
+    if (attributedString)
+        [ts setAttributedString:attributedString];
     [ts endEditing];
     [drawText setAlignment:NSLeftTextAlignment];
     [drawText setString:s];
@@ -277,7 +278,7 @@ static void initClassVars()
     }
     if (color)
         [drawText setTextColor:color];
-    [drawText sizeToFit];	/* collapses to zero for text larger bounds ??? */
+    [drawText sizeToFit];	// collapses to zero for text larger bounds ???
 
     [self setAttributedString:[ts attributedSubstringFromRange:NSMakeRange(0, [ts length])]];
     [[drawText textContainer] setWidthTracksTextView:YES];
@@ -1025,7 +1026,7 @@ static void initClassVars()
 
         [[drawText textStorage] endEditing];
         [drawText setFrame:bounds];
-        //[drawText writeRTFDToFile:@"/tmp/text.rtf" atomically:NO];	// test
+        //[drawText writeRTFDToFile:@"/tmp/text.rtf" atomically:NO];	// debugging
         //[drawText setFrame:bounds];
 
         [drawText setTextContainerInset:NSMakeSize(0.0, 0.0)];
@@ -1615,7 +1616,7 @@ static void initClassVars()
             [pathG setWidth:0.0];
             if (aspectRatio != 1.0)
                 [pathG scale:1.0 :aspectRatio
-                  withCenter:NSMakePoint(1.0, bRect.origin.x+bRect.size.height/2.0)];
+                  withCenter:NSMakePoint(1.0, bRect.origin.y+bRect.size.height/2.0)];
             [pathG setAngle:-rotAngle withCenter:bRect.origin];
             /* FIXME: stroked fonts shouldn't be filled! */
             [pathG setFilled:YES optimize:NO];
